@@ -1,5 +1,5 @@
 package DBIx::Class::CryptColumn;
-$DBIx::Class::CryptColumn::VERSION = '0.006';
+$DBIx::Class::CryptColumn::VERSION = '0.007';
 use strict;
 use warnings;
 
@@ -57,7 +57,7 @@ sub register_column {
 				my $hash = $row->get_column($column);
 				my $result = $crypt_passphrase->verify_password($password, $hash);
 				if ($result && $crypt_passphrase->needs_rehash($hash)) {
-					$row->update($column, $password);
+					$row->update({ $column => $password })->discard_changes;
 				}
 
 				return $result;
@@ -79,6 +79,12 @@ sub set_column {
 	return $self->next::method($col, $val, @rest);
 }
 
+sub set_inflated_column {
+	my ($self, $col, $val, @rest) = @_;
+	local $self->column_info($col)->{inflate_passphrase};
+	$self->next::method($col, $val, @rest);
+}
+
 1;
 
 # ABSTRACT: Automatically hash password/passphrase columns
@@ -95,7 +101,7 @@ DBIx::Class::CryptColumn - Automatically hash password/passphrase columns
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -194,6 +200,10 @@ normally be directly called by end users.
 
 Hash a passphrase column whenever it is set.
 
+=head2 set_inflated_column
+
+Sets an inflated password column that does not need to be hashed again.
+
 =head2 new
 
 Hash all passphrase columns on C<new()> so that C<copy()>, C<create()>, and
